##
##  tldx.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2025 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
%define       V_tldx_base  1.0.0
%define       V_tldx_snap  20250601

#   package information
Name:         tldx
Summary:      Top-Level Domain Discovery Tool
URL:          https://github.com/brandonyoungdev/tldx
Vendor:       Brandon Young
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Networking
License:      Apache
Version:      %{V_tldx_base}.%{V_tldx_snap}
Release:      20250601

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/tldx/tldx-%{V_tldx_snap}.tar.xz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101

%description
    tldx(1) helps you brainstorm available top-level domain names fast.
    It features smart keyword-based domain permutations (prefixes,
    suffixes, TLDs), provides fast and concurrent WHOIS availability
    checks, streams results as they're found, and has optional filtering
    by domain length.

%track
    prog tldx:base = {
        version   = %{V_tldx_base}
        url       = https://github.com/brandonyoungdev/tldx/releases
        regex     = tree/v(\d+\.\d+\.\d+)
    }
    prog tldx:snap = {
        version   = %{V_tldx_snap}
        url       = http://download.openpkg.org/components/versioned/tldx/
        regex     = tldx-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n tldx

%build
    #   build program
    export GOPATH=`pwd`
    cd $GOPATH/src/github.com/brandonyoungdev/tldx
    go build -v -o tldx .

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/github.com/brandonyoungdev/tldx/tldx \
        $RPM_BUILD_ROOT%{l_prefix}/bin/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

